from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Int, Boolean, Float

Soapdenovo_127Mer_All_V0_1_0 = CommandToolBuilder(tool="SOAPdenovo_127mer_all", base_command=["SOAPdenovo-127mer", "all"], inputs=[ToolInput(tag="in_config_file_solexa", input_type=File(optional=True), prefix="-s", doc=InputDocumentation(doc="configFile: the config file of solexa reads")), ToolInput(tag="in_outputgraph_prefix_output", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc="outputGraph: prefix of output graph file name")), ToolInput(tag="in_kmermin_max_size", input_type=Int(optional=True), prefix="-K", doc=InputDocumentation(doc="kmer(min 13, max 127): kmer size, [23]")), ToolInput(tag="in_ncpu_number_cpu", input_type=Int(optional=True), prefix="-p", doc=InputDocumentation(doc="n_cpu: number of cpu for use, [8]")), ToolInput(tag="in_initmemoryassumption_memory_assumption", input_type=Int(optional=True), prefix="-a", doc=InputDocumentation(doc="initMemoryAssumption: memory assumption initialized to avoid further reallocation, unit G, [0]")), ToolInput(tag="in_kmerfreqcutoff_kmers_larger", input_type=Int(optional=True), prefix="-d", doc=InputDocumentation(doc="kmerFreqCutoff: kmers with frequency no larger than KmerFreqCutoff will be deleted, [0]")), ToolInput(tag="in_optional_resolve_repeats", input_type=Boolean(optional=True), prefix="-R", doc=InputDocumentation(doc="(optional)  resolve repeats by reads, [NO]")), ToolInput(tag="in_edgecovcutoff_edges_larger", input_type=Int(optional=True), prefix="-D", doc=InputDocumentation(doc="edgeCovCutoff: edges with coverage no larger than EdgeCovCutoff will be deleted, [1]")), ToolInput(tag="in_mergelevelmin_max_strength", input_type=Int(optional=True), prefix="-M", doc=InputDocumentation(doc="mergeLevel(min 0, max 3): the strength of merging similar sequences during contiging, [1]")), ToolInput(tag="in_arcweight_two_edges", input_type=Int(optional=True), prefix="-e", doc=InputDocumentation(doc="arcWeight: two edges, between which the arc's weight is larger than arcWeight, will be linerized, [0]")), ToolInput(tag="in_maxkmer_max_size", input_type=Int(optional=True), prefix="-m", doc=InputDocumentation(doc="maxKmer (max 127): maximum kmer size used for multi-kmer, [NO]")), ToolInput(tag="in_optional_merge_bubble", input_type=Boolean(optional=True), prefix="-E", doc=InputDocumentation(doc="(optional)  merge clean bubble before iterate, works only if -M is set when using multi-kmer, [NO]")), ToolInput(tag="in_max_kmer_size", input_type=Int(optional=True), prefix="-k", doc=InputDocumentation(doc="kmer_R2C(min 13, max 127): kmer size used for mapping reads to contigs, [K]")), ToolInput(tag="in_optional_fill_gaps", input_type=Boolean(optional=True), prefix="-F", doc=InputDocumentation(doc="(optional)  fill gaps in scaffolds, [NO]")), ToolInput(tag="in_optional_unmask_contigs", input_type=Boolean(optional=True), prefix="-u", doc=InputDocumentation(doc="(optional)  un-mask contigs with high/low coverage before scaffolding, [mask]")), ToolInput(tag="in_optional_keep_contigs", input_type=Boolean(optional=True), prefix="-w", doc=InputDocumentation(doc="(optional)  keep contigs weakly connected to other contigs in scaffold, [NO]")), ToolInput(tag="in_gaplendiff_allowed_difference", input_type=Int(optional=True), prefix="-G", doc=InputDocumentation(doc="gapLenDiff: allowed length difference between estimated and filled gap, [50]")), ToolInput(tag="in_shortest_contig_scaffolding", input_type=Int(optional=True), prefix="-L", doc=InputDocumentation(doc="minContigLen: shortest contig for scaffolding, [K+2]")), ToolInput(tag="in_mincontigcvg_minimum_contig", input_type=Float(optional=True), prefix="-c", doc=InputDocumentation(doc="minContigCvg: minimum contig coverage (c*avgCvg), contigs shorter than 100bp with coverage smaller than c*avgCvg will be masked before scaffolding unless -u is set, [0.1]")), ToolInput(tag="in_maxcontigcvg_maximum_contig", input_type=Float(optional=True), prefix="-C", doc=InputDocumentation(doc="maxContigCvg: maximum contig coverage (C*avgCvg), contigs with coverage larger than C*avgCvg or contigs shorter than 100bp with coverage larger than 0.8*C*avgCvg will be masked before scaffolding unless -u is set, [2]")), ToolInput(tag="in_insertsizeupperbound_bavgins_used", input_type=Float(optional=True), prefix="-b", doc=InputDocumentation(doc="insertSizeUpperBound: (b*avg_ins) will be used as upper bound of insert size for large insert size ( > 1000) when handling pair-end connections between contigs if b is set to larger than 1, [1.5]")), ToolInput(tag="in_bubblecoverage_remove_contig", input_type=Float(optional=True), prefix="-B", doc=InputDocumentation(doc="bubbleCoverage: remove contig with lower cvoerage in bubble structure if both contigs' coverage are smaller than bubbleCoverage*avgCvg, [0.6]")), ToolInput(tag="in_genomesize_genome_size", input_type=Int(optional=True), prefix="-N", doc=InputDocumentation(doc="genomeSize: genome size for statistics, [0]")), ToolInput(tag="in_optional_output_information", input_type=Boolean(optional=True), prefix="-V", doc=InputDocumentation(doc="(optional)  output information for Hawkeye to visualize the assembly, [NO]")), ToolInput(tag="in_soapdenovo_s_configfile", input_type=Int(), position=0, doc=InputDocumentation(doc="SOAPdenovo all -s configFile -o outputGraph [-R -F -u -w] [-K kmer -p n_cpu -a initMemoryAssumption -d KmerFreqCutOff -D EdgeCovCutoff -M mergeLevel -k kmer_R2C, -G gapLenDiff -L minContigLen -c minContigCvg -C maxContigCvg -b insertSizeUpperBound -B bubbleCoverage -N genomeSize]"))], outputs=[ToolOutput(tag="out_outputgraph_prefix_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_outputgraph_prefix_output", type_hint=File()), doc=OutputDocumentation(doc="outputGraph: prefix of output graph file name"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Soapdenovo_127Mer_All_V0_1_0().translate("wdl", allow_empty_container=True)

